==> cloudt-boot-starter-web-3.3.19-0426-20240425.033646-2-sources.jar: com/elitescloud/boot/web/config/CloudtWebAutoConfiguration.java <==
package com.elitescloud.boot.web.config;

import cn.hutool.core.util.StrUtil;
import com.elitescloud.boot.common.servlet.CloudtRequestAttributes;
import com.elitescloud.boot.support.CloudtInterceptor;
import com.elitescloud.boot.support.app.CloudtAppHolder;
import com.elitescloud.boot.threadpool.common.ContextTransfer;
import com.elitescloud.boot.web.config.filter.WebRequestCommonInterceptor;
import com.elitescloud.boot.web.config.support.InterceptorInvocableHandlerMethodCustomizer;
import com.elitescloud.boot.web.exception.GlobalExceptionHandler;
import com.elitescloud.cloudt.common.base.ApiResult;
import org.springframework.beans.factory.InitializingBean;
import org.springframework.beans.factory.ObjectProvider;
import org.springframework.boot.context.properties.EnableConfigurationProperties;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Import;
import org.springframework.util.StringUtils;

import java.util.HashMap;
import java.util.Map;

/**
 * web自动化配置.
 *
 * @author Kaiser（wang shao）
 * @date 3/20/2023
 */
@Import({WebRepeatRequestConfig.class})
@EnableConfigurationProperties({CloudtExceptionProperties.class})
class CloudtWebAutoConfiguration implements InitializingBean {

    private final CloudtExceptionProperties exceptionProperties;

    public CloudtWebAutoConfiguration(CloudtExceptionProperties exceptionProperties) {
        this.exceptionProperties = exceptionProperties;
    }

    @Override
    public void afterPropertiesSet() throws Exception {
        // 异常转换
        if (StringUtils.hasText(exceptionProperties.getGlobal().getDefaultMsgFormat())) {
            ApiResult.setErrorMsgConvert((errorCode, errorNo) -> {
                Map<String, String> params = new HashMap<>(4);
                params.put("appName", CloudtAppHolder.getAppName());
                params.put("errorNo", errorNo);
                return StrUtil.format(exceptionProperties.getGlobal().getDefaultMsgFormat(), params);
            });
        }
    }

    @Bean
    public WebRequestCommonInterceptor cloudtInterceptorWeb() {
        return new WebRequestCommonInterceptor();
    }

    @Bean
    public InterceptorInvocableHandlerMethodCustomizer interceptorInvocableHandlerMethodCustomizer(ObjectProvider<CloudtInterceptor> interceptors) {
        return new InterceptorInvocableHandlerMethodCustomizer(interceptors);
    }

    /**
     * 全局异常处理
     *
     * @return 异常处理器
     */
    @Bean
    public GlobalExceptionHandler globalExceptionHandler() {
        return new GlobalExceptionHandler(exceptionProperties);
    }

    /**
     * 请求信息的上下文传递
     *
     * @return 上下文传递器
     */
    @Bean
    public ContextTransfer<CloudtRequestAttributes> contextTransferRequestAttributes() {
        return new ServletRequestContextTransfer();
    }
}

==> cloudt-boot-starter-web-3.3.20-0512-20240430.015028-3-sources.jar: com/elitescloud/boot/web/config/CloudtWebAutoConfiguration.java <==
package com.elitescloud.boot.web.config;

import cn.hutool.core.util.StrUtil;
import com.elitescloud.boot.common.servlet.CloudtRequestAttributes;
import com.elitescloud.boot.support.CloudtInterceptor;
import com.elitescloud.boot.support.app.CloudtAppHolder;
import com.elitescloud.boot.threadpool.common.ContextTransfer;
import com.elitescloud.boot.web.config.filter.WebRequestCommonInterceptor;
import com.elitescloud.boot.web.config.support.InterceptorInvocableHandlerMethodCustomizer;
import com.elitescloud.boot.web.exception.GlobalExceptionHandler;
import com.elitescloud.cloudt.common.base.ApiResult;
import org.springframework.beans.factory.InitializingBean;
import org.springframework.beans.factory.ObjectProvider;
import org.springframework.boot.context.properties.EnableConfigurationProperties;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Import;
import org.springframework.util.StringUtils;

import java.util.HashMap;
import java.util.Map;

/**
 * web自动化配置.
 *
 * @author Kaiser（wang shao）
 * @date 3/20/2023
 */
@Import({WebRepeatRequestConfig.class})
@EnableConfigurationProperties({CloudtExceptionProperties.class})
class CloudtWebAutoConfiguration implements InitializingBean {

    private final CloudtExceptionProperties exceptionProperties;

    public CloudtWebAutoConfiguration(CloudtExceptionProperties exceptionProperties) {
        this.exceptionProperties = exceptionProperties;
    }

    @Override
    public void afterPropertiesSet() throws Exception {
        // 异常转换
        if (StringUtils.hasText(exceptionProperties.getGlobal().getDefaultMsgFormat())) {
            ApiResult.setErrorMsgConvert((errorCode, errorNo) -> {
                Map<String, String> params = new HashMap<>(4);
                params.put("appName", CloudtAppHolder.getAppName());
                params.put("errorNo", errorNo);
                return StrUtil.format(exceptionProperties.getGlobal().getDefaultMsgFormat(), params);
            });
        }
    }

    @Bean
    public WebRequestCommonInterceptor cloudtInterceptorWeb(WebProperties webProperties) {
        return new WebRequestCommonInterceptor(webProperties);
    }

    @Bean
    public InterceptorInvocableHandlerMethodCustomizer interceptorInvocableHandlerMethodCustomizer(ObjectProvider<CloudtInterceptor> interceptors) {
        return new InterceptorInvocableHandlerMethodCustomizer(interceptors);
    }

    /**
     * 全局异常处理
     *
     * @return 异常处理器
     */
    @Bean
    public GlobalExceptionHandler globalExceptionHandler() {
        return new GlobalExceptionHandler(exceptionProperties);
    }

    /**
     * 请求信息的上下文传递
     *
     * @return 上下文传递器
     */
    @Bean
    public ContextTransfer<CloudtRequestAttributes> contextTransferRequestAttributes() {
        return new ServletRequestContextTransfer();
    }
}
